==> kom%2B%2B-0.3.tar.gz: kom++-0.3/libconnection/014add_member_q.cc <==
// Add a member to a conference.
//
// $Id: 014add_member_q.cc,v 1.2 1994/07/16 17:33:15 ceder Exp $
// Copyright (C) 1994  Per Cederqvist and Inge Wallin
//
// This program is free software; you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation; either version 2 of the License, or
// (at your option) any later version.
// 
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
// 
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.

#include <iostream.h>
#include <assert.h>
#include "prot-a-LyStr.h"
#include "question.h"
#include "connection.h"
#include "add_member_q.h"

    
add_member_question::add_member_question(Connection *conn,
					 Conf_no cno, 
					 Pers_no pno, 
					 unsigned char priority,
					 unsigned short placement)
    : question(conn)
{
    prot_a_LyStr   s;

    s << ref_no() << " 14 " << cno << ' ' << pno << ' ' <<  int(priority)
	<< ' ' << placement << '\n';
    port->send_question(s);
}


add_member_question::~add_member_question()
{
}


void
add_member_question::parser(prot_a_LyStr &str)
{
    state = st_ok;
    deallocate_refno();
}


void
add_member_question::result()
{
    return;
}

==> kom%2B%2B-0.5.tar.gz: kom++-0.5/libconnection/014add_member_q.cc <==
// Add a member to a conference.
//
// $Id: 014add_member_q.cc,v 1.4 1995/11/14 06:06:19 ceder Exp $
// Copyright (C) 1994  Per Cederqvist and Inge Wallin
//
// This program is free software; you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation; either version 2 of the License, or
// (at your option) any later version.
// 
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
// 
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.

#include <iostream.h>
#include <assert.h>
#include "prot-a-LyStr.h"
#include "question.h"
#include "connection.h"
#include "add_member_q.h"

    
add_member_question::add_member_question(Connection *conn,
					 Conf_no cno, 
					 Pers_no pno, 
					 unsigned char priority,
					 unsigned short placement)
    : question(conn)
{
    prot_a_LyStr   s;

    s << ref_no() << " 14 " << cno << ' ' << pno << ' ' <<  int(priority)
	<< ' ' << placement << '\n';
    port->send_question(s);
}


add_member_question::~add_member_question()
{
}


void
add_member_question::parser(prot_a_LyStr &)
{
    state = st_ok;
    deallocate_refno();
}


void
add_member_question::result()
{
    return;
}
